@@ -5,13 +5,18 @@ import time
 import typer
 import yaml
 from SPARQLWrapper import SPARQLWrapper, SPARQLExceptions, GET, DIGEST, JSON
+from urllib import error
 
 app = typer.Typer()
 
 
-# TODO: Query other data platforms
-
 def query1(company: str):
+    """
+    Given a company it returns all the products that
+    are currently sold by that company
+    :param company:
+    :return: products
+    """
     return "PREFIX rdf: <http://www.w3.org/1999/02/22-rdf-syntax-ns#>\
             PREFIX owl: <http://www.w3.org/2002/07/owl#>\
             PREFIX rdfs: <http://www.w3.org/2000/01/rdf-schema#>\
@@ -26,6 +31,12 @@ def query1(company: str):
 
 
 def query2(company: str):
+    """
+    Given a company it returns all the subcompanies related
+    to the input company
+    :param company:
+    :return: companies
+    """
     return "PREFIX rdf: <http://www.w3.org/1999/02/22-rdf-syntax-ns#>\
             PREFIX owl: <http://www.w3.org/2002/07/owl#>\
             PREFIX rdfs: <http://www.w3.org/2000/01/rdf-schema#>\
@@ -61,6 +72,13 @@ def query3(product: str):
 
 
 def query4(person: str):
+    """
+    Given a user, it returns all the products that the
+    user bought from one of the companies listed in the
+    productCatalog itself
+    :param person:
+    :return: products
+    """
     return "PREFIX rdf: <http://www.w3.org/1999/02/22-rdf-syntax-ns#>\
             PREFIX sipg: <https://evilscript.altervista.org/productCatalog.owl#>\
             SELECT ?prod WHERE{\
@@ -71,11 +89,18 @@ def query4(person: str):
 
 
 def show_results(results: dict, opt_column: str):
+    # First, we take the colums that the user wants to see from input or from the optional parameter
+    print("Le colonne disponibili dalla query sono: ", end="")
+    for key, value in results["results"].items():
+        for kex in value[0].keys():
+            print(kex, end=" ")
+
     if opt_column == "":
-        colonna = input("Inserisci il nome della colonne che vuoi visualizzare, separate da una virgola: ").split(",")
+        colonna = input("\nInserisci il nome della colonne che vuoi visualizzare, separate da una virgola: ").split(",")
     else:
         colonna = opt_column.split(",")
 
+    # We initialize a cool progressbar that will be showed during slow online queries
     with typer.progressbar(results["results"]["bindings"], label="Progress") as progress:
         for result in progress:
             for res in colonna:
@@ -88,6 +113,7 @@ def show_results(results: dict, opt_column: str):
 
     confirm = typer.confirm("Vuoi esportare i tuoi dati in un file?")
     if confirm:
+        # If the user says so, we can output the results (even the columns that weren't shown)
         file_name = input("Inserisci il nome del file: ")
         with open(file_name, "w") as text_file:
             pretty_output = yaml.dump(results, default_flow_style=False)
@@ -108,12 +134,18 @@ def do_query(sqlery: str, opt_column: str = ""):
     # Then we recover the query results with a try except
     try:
         ret = sparql.query().convert()
-        # Results are stored in JSON ff
+        # Results are stored in JSON
         show_results(ret, opt_column)
     except SPARQLExceptions.EndPointNotFound as err:
         typer.secho(f"Errore: non riesco a trovare il server GraphDB!", fg=typer.colors.RED)
         typer.echo(err)
-    # Then, we show the results
+    except error.URLError:
+        typer.secho("Errore: il server GraphDB sembra spento o non correttamente avviato, accertati del suo "
+                    "funzionamento!", fg=typer.colors.RED)
+    except SPARQLExceptions.QueryBadFormed:
+        typer.secho("La query in input non è corretta, accertati che sia scritta correttamente e non contenga"
+                    "doppi apici nel caso in cui tu sia in standard query mode!", fg=typer.colors.RED)
+    # Then, we show the results, or the error if it enters in the except
 
 
 @app.command()
